<h1 align="center">摸鱼办公室 🐟</h1>

<p align="center">
🐟🐟🐟🐟🐟🐟🐟🐟🐟🐟🐟🐟
</p>

<center>
你好，摸鱼人，工作再累，一定不要忘记摸鱼哦 !
有事没事起身去茶水间去廊道去天台走走，别老在工位上坐着。
多喝点水，钱是老板的，但命是自己的 !
</center>
<br><br>


<p align="right">摸鱼办 宣 </p>